| Copyright | (c) 2013-2023 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | Safe-Inferred |
| Language | Haskell2010 |
Amazonka.BillingConductor.Types.CustomLineItemListElement
Description
Synopsis
- data CustomLineItemListElement = CustomLineItemListElement' {
- arn :: Maybe Text
- associationSize :: Maybe Natural
- billingGroupArn :: Maybe Text
- chargeDetails :: Maybe ListCustomLineItemChargeDetails
- creationTime :: Maybe Integer
- currencyCode :: Maybe CurrencyCode
- description :: Maybe (Sensitive Text)
- lastModifiedTime :: Maybe Integer
- name :: Maybe (Sensitive Text)
- productCode :: Maybe Text
- newCustomLineItemListElement :: CustomLineItemListElement
- customLineItemListElement_arn :: Lens' CustomLineItemListElement (Maybe Text)
- customLineItemListElement_associationSize :: Lens' CustomLineItemListElement (Maybe Natural)
- customLineItemListElement_billingGroupArn :: Lens' CustomLineItemListElement (Maybe Text)
- customLineItemListElement_chargeDetails :: Lens' CustomLineItemListElement (Maybe ListCustomLineItemChargeDetails)
- customLineItemListElement_creationTime :: Lens' CustomLineItemListElement (Maybe Integer)
- customLineItemListElement_currencyCode :: Lens' CustomLineItemListElement (Maybe CurrencyCode)
- customLineItemListElement_description :: Lens' CustomLineItemListElement (Maybe Text)
- customLineItemListElement_lastModifiedTime :: Lens' CustomLineItemListElement (Maybe Integer)
- customLineItemListElement_name :: Lens' CustomLineItemListElement (Maybe Text)
- customLineItemListElement_productCode :: Lens' CustomLineItemListElement (Maybe Text)
Documentation
data CustomLineItemListElement Source #
A representation of a custom line item.
See: newCustomLineItemListElement smart constructor.
Constructors
| CustomLineItemListElement' | |
Fields
| |
Instances
newCustomLineItemListElement :: CustomLineItemListElement Source #
Create a value of CustomLineItemListElement with all optional fields omitted.
Use generic-lens or optics to modify other optional fields.
The following record fields are available, with the corresponding lenses provided for backwards compatibility:
$sel:arn:CustomLineItemListElement', customLineItemListElement_arn - The Amazon Resource Names (ARNs) for custom line items.
$sel:associationSize:CustomLineItemListElement', customLineItemListElement_associationSize - The number of resources that are associated to the custom line item.
$sel:billingGroupArn:CustomLineItemListElement', customLineItemListElement_billingGroupArn - The Amazon Resource Name (ARN) that references the billing group where
the custom line item applies to.
$sel:chargeDetails:CustomLineItemListElement', customLineItemListElement_chargeDetails - A ListCustomLineItemChargeDetails that describes the charge details of
a custom line item.
$sel:creationTime:CustomLineItemListElement', customLineItemListElement_creationTime - The time created.
$sel:currencyCode:CustomLineItemListElement', customLineItemListElement_currencyCode - The custom line item's charge value currency. Only one of the valid
values can be used.
$sel:description:CustomLineItemListElement', customLineItemListElement_description - The custom line item's description. This is shown on the Bills page in
association with the charge value.
$sel:lastModifiedTime:CustomLineItemListElement', customLineItemListElement_lastModifiedTime - The most recent time when the custom line item was modified.
$sel:name:CustomLineItemListElement', customLineItemListElement_name - The custom line item's name.
$sel:productCode:CustomLineItemListElement', customLineItemListElement_productCode - The product code that's associated with the custom line item.
customLineItemListElement_arn :: Lens' CustomLineItemListElement (Maybe Text) Source #
The Amazon Resource Names (ARNs) for custom line items.
customLineItemListElement_associationSize :: Lens' CustomLineItemListElement (Maybe Natural) Source #
The number of resources that are associated to the custom line item.
customLineItemListElement_billingGroupArn :: Lens' CustomLineItemListElement (Maybe Text) Source #
The Amazon Resource Name (ARN) that references the billing group where the custom line item applies to.
customLineItemListElement_chargeDetails :: Lens' CustomLineItemListElement (Maybe ListCustomLineItemChargeDetails) Source #
A ListCustomLineItemChargeDetails that describes the charge details of
a custom line item.
customLineItemListElement_creationTime :: Lens' CustomLineItemListElement (Maybe Integer) Source #
The time created.
customLineItemListElement_currencyCode :: Lens' CustomLineItemListElement (Maybe CurrencyCode) Source #
The custom line item's charge value currency. Only one of the valid values can be used.
customLineItemListElement_description :: Lens' CustomLineItemListElement (Maybe Text) Source #
The custom line item's description. This is shown on the Bills page in association with the charge value.
customLineItemListElement_lastModifiedTime :: Lens' CustomLineItemListElement (Maybe Integer) Source #
The most recent time when the custom line item was modified.
customLineItemListElement_name :: Lens' CustomLineItemListElement (Maybe Text) Source #
The custom line item's name.
customLineItemListElement_productCode :: Lens' CustomLineItemListElement (Maybe Text) Source #
The product code that's associated with the custom line item.