| Copyright | (c) 2013-2023 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | Safe-Inferred |
| Language | Haskell2010 |
Amazonka.BillingConductor.Types.CustomLineItemPercentageChargeDetails
Description
Synopsis
- data CustomLineItemPercentageChargeDetails = CustomLineItemPercentageChargeDetails' {}
- newCustomLineItemPercentageChargeDetails :: Double -> CustomLineItemPercentageChargeDetails
- customLineItemPercentageChargeDetails_associatedValues :: Lens' CustomLineItemPercentageChargeDetails (Maybe [Text])
- customLineItemPercentageChargeDetails_percentageValue :: Lens' CustomLineItemPercentageChargeDetails Double
Documentation
data CustomLineItemPercentageChargeDetails Source #
A representation of the charge details that are associated with a percentage custom line item.
See: newCustomLineItemPercentageChargeDetails smart constructor.
Constructors
| CustomLineItemPercentageChargeDetails' | |
Fields
| |
Instances
newCustomLineItemPercentageChargeDetails Source #
Arguments
| :: Double | |
| -> CustomLineItemPercentageChargeDetails |
Create a value of CustomLineItemPercentageChargeDetails with all optional fields omitted.
Use generic-lens or optics to modify other optional fields.
The following record fields are available, with the corresponding lenses provided for backwards compatibility:
$sel:associatedValues:CustomLineItemPercentageChargeDetails', customLineItemPercentageChargeDetails_associatedValues - A list of resource ARNs to associate to the percentage custom line item.
$sel:percentageValue:CustomLineItemPercentageChargeDetails', customLineItemPercentageChargeDetails_percentageValue - The custom line item's percentage value. This will be multiplied
against the combined value of its associated resources to determine its
charge value.
customLineItemPercentageChargeDetails_associatedValues :: Lens' CustomLineItemPercentageChargeDetails (Maybe [Text]) Source #
A list of resource ARNs to associate to the percentage custom line item.
customLineItemPercentageChargeDetails_percentageValue :: Lens' CustomLineItemPercentageChargeDetails Double Source #
The custom line item's percentage value. This will be multiplied against the combined value of its associated resources to determine its charge value.