| Copyright | (c) 2013-2023 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | Safe-Inferred |
| Language | Haskell2010 |
Amazonka.BillingConductor.Types.CustomLineItemVersionListElement
Description
Synopsis
- data CustomLineItemVersionListElement = CustomLineItemVersionListElement' {
- associationSize :: Maybe Natural
- billingGroupArn :: Maybe Text
- chargeDetails :: Maybe ListCustomLineItemChargeDetails
- creationTime :: Maybe Integer
- currencyCode :: Maybe CurrencyCode
- description :: Maybe (Sensitive Text)
- endBillingPeriod :: Maybe Text
- lastModifiedTime :: Maybe Integer
- name :: Maybe (Sensitive Text)
- productCode :: Maybe Text
- startBillingPeriod :: Maybe Text
- newCustomLineItemVersionListElement :: CustomLineItemVersionListElement
- customLineItemVersionListElement_associationSize :: Lens' CustomLineItemVersionListElement (Maybe Natural)
- customLineItemVersionListElement_billingGroupArn :: Lens' CustomLineItemVersionListElement (Maybe Text)
- customLineItemVersionListElement_chargeDetails :: Lens' CustomLineItemVersionListElement (Maybe ListCustomLineItemChargeDetails)
- customLineItemVersionListElement_creationTime :: Lens' CustomLineItemVersionListElement (Maybe Integer)
- customLineItemVersionListElement_currencyCode :: Lens' CustomLineItemVersionListElement (Maybe CurrencyCode)
- customLineItemVersionListElement_description :: Lens' CustomLineItemVersionListElement (Maybe Text)
- customLineItemVersionListElement_endBillingPeriod :: Lens' CustomLineItemVersionListElement (Maybe Text)
- customLineItemVersionListElement_lastModifiedTime :: Lens' CustomLineItemVersionListElement (Maybe Integer)
- customLineItemVersionListElement_name :: Lens' CustomLineItemVersionListElement (Maybe Text)
- customLineItemVersionListElement_productCode :: Lens' CustomLineItemVersionListElement (Maybe Text)
- customLineItemVersionListElement_startBillingPeriod :: Lens' CustomLineItemVersionListElement (Maybe Text)
Documentation
data CustomLineItemVersionListElement Source #
A representation of a custom line item version.
See: newCustomLineItemVersionListElement smart constructor.
Constructors
| CustomLineItemVersionListElement' | |
Fields
| |
Instances
newCustomLineItemVersionListElement :: CustomLineItemVersionListElement Source #
Create a value of CustomLineItemVersionListElement with all optional fields omitted.
Use generic-lens or optics to modify other optional fields.
The following record fields are available, with the corresponding lenses provided for backwards compatibility:
$sel:associationSize:CustomLineItemVersionListElement', customLineItemVersionListElement_associationSize - The number of resources that are associated with the custom line item.
$sel:billingGroupArn:CustomLineItemVersionListElement', customLineItemVersionListElement_billingGroupArn - The Amazon Resource Name (ARN) of the billing group that the custom line
item applies to.
$sel:chargeDetails:CustomLineItemVersionListElement', customLineItemVersionListElement_chargeDetails - Undocumented member.
$sel:creationTime:CustomLineItemVersionListElement', customLineItemVersionListElement_creationTime - The time when the custom line item version was created.
$sel:currencyCode:CustomLineItemVersionListElement', customLineItemVersionListElement_currencyCode - The charge value currency of the custom line item.
$sel:description:CustomLineItemVersionListElement', customLineItemVersionListElement_description - The description of the custom line item.
$sel:endBillingPeriod:CustomLineItemVersionListElement', customLineItemVersionListElement_endBillingPeriod - The end billing period of the custom line item version.
$sel:lastModifiedTime:CustomLineItemVersionListElement', customLineItemVersionListElement_lastModifiedTime - The most recent time that the custom line item version was modified.
$sel:name:CustomLineItemVersionListElement', customLineItemVersionListElement_name - The name of the custom line item.
$sel:productCode:CustomLineItemVersionListElement', customLineItemVersionListElement_productCode - The product code that’s associated with the custom line item.
$sel:startBillingPeriod:CustomLineItemVersionListElement', customLineItemVersionListElement_startBillingPeriod - The start billing period of the custom line item version.
customLineItemVersionListElement_associationSize :: Lens' CustomLineItemVersionListElement (Maybe Natural) Source #
The number of resources that are associated with the custom line item.
customLineItemVersionListElement_billingGroupArn :: Lens' CustomLineItemVersionListElement (Maybe Text) Source #
The Amazon Resource Name (ARN) of the billing group that the custom line item applies to.
customLineItemVersionListElement_chargeDetails :: Lens' CustomLineItemVersionListElement (Maybe ListCustomLineItemChargeDetails) Source #
Undocumented member.
customLineItemVersionListElement_creationTime :: Lens' CustomLineItemVersionListElement (Maybe Integer) Source #
The time when the custom line item version was created.
customLineItemVersionListElement_currencyCode :: Lens' CustomLineItemVersionListElement (Maybe CurrencyCode) Source #
The charge value currency of the custom line item.
customLineItemVersionListElement_description :: Lens' CustomLineItemVersionListElement (Maybe Text) Source #
The description of the custom line item.
customLineItemVersionListElement_endBillingPeriod :: Lens' CustomLineItemVersionListElement (Maybe Text) Source #
The end billing period of the custom line item version.
customLineItemVersionListElement_lastModifiedTime :: Lens' CustomLineItemVersionListElement (Maybe Integer) Source #
The most recent time that the custom line item version was modified.
customLineItemVersionListElement_name :: Lens' CustomLineItemVersionListElement (Maybe Text) Source #
The name of the custom line item.
customLineItemVersionListElement_productCode :: Lens' CustomLineItemVersionListElement (Maybe Text) Source #
The product code that’s associated with the custom line item.
customLineItemVersionListElement_startBillingPeriod :: Lens' CustomLineItemVersionListElement (Maybe Text) Source #
The start billing period of the custom line item version.