| Copyright | (c) 2013-2023 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | Safe-Inferred |
| Language | Haskell2010 |
Amazonka.BillingConductor.Types.ListCustomLineItemPercentageChargeDetails
Description
Synopsis
- data ListCustomLineItemPercentageChargeDetails = ListCustomLineItemPercentageChargeDetails' {}
- newListCustomLineItemPercentageChargeDetails :: Double -> ListCustomLineItemPercentageChargeDetails
- listCustomLineItemPercentageChargeDetails_percentageValue :: Lens' ListCustomLineItemPercentageChargeDetails Double
Documentation
data ListCustomLineItemPercentageChargeDetails Source #
A representation of the charge details that are associated with a percentage custom line item.
See: newListCustomLineItemPercentageChargeDetails smart constructor.
Constructors
| ListCustomLineItemPercentageChargeDetails' | |
Fields
| |
Instances
newListCustomLineItemPercentageChargeDetails Source #
Arguments
| :: Double |
|
| -> ListCustomLineItemPercentageChargeDetails |
Create a value of ListCustomLineItemPercentageChargeDetails with all optional fields omitted.
Use generic-lens or optics to modify other optional fields.
The following record fields are available, with the corresponding lenses provided for backwards compatibility:
$sel:percentageValue:ListCustomLineItemPercentageChargeDetails', listCustomLineItemPercentageChargeDetails_percentageValue - The custom line item's percentage value. This will be multiplied
against the combined value of its associated resources to determine its
charge value.
listCustomLineItemPercentageChargeDetails_percentageValue :: Lens' ListCustomLineItemPercentageChargeDetails Double Source #
The custom line item's percentage value. This will be multiplied against the combined value of its associated resources to determine its charge value.