| Copyright | (c) 2013-2023 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | Safe-Inferred |
| Language | Haskell2010 |
Amazonka.BillingConductor.Types.ListCustomLineItemVersionsFilter
Description
Synopsis
Documentation
data ListCustomLineItemVersionsFilter Source #
A filter that specifies the billing period range where the custom line item versions reside.
See: newListCustomLineItemVersionsFilter smart constructor.
Constructors
| ListCustomLineItemVersionsFilter' | |
Fields
| |
Instances
newListCustomLineItemVersionsFilter :: ListCustomLineItemVersionsFilter Source #
Create a value of ListCustomLineItemVersionsFilter with all optional fields omitted.
Use generic-lens or optics to modify other optional fields.
The following record fields are available, with the corresponding lenses provided for backwards compatibility:
$sel:billingPeriodRange:ListCustomLineItemVersionsFilter', listCustomLineItemVersionsFilter_billingPeriodRange - The billing period range in which the custom line item version is
applied.
listCustomLineItemVersionsFilter_billingPeriodRange :: Lens' ListCustomLineItemVersionsFilter (Maybe ListCustomLineItemVersionsBillingPeriodRangeFilter) Source #
The billing period range in which the custom line item version is applied.