| Copyright | (c) 2013-2023 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | Safe-Inferred |
| Language | Haskell2010 |
Amazonka.BillingConductor.Types.ListResourcesAssociatedToCustomLineItemFilter
Description
Synopsis
- data ListResourcesAssociatedToCustomLineItemFilter = ListResourcesAssociatedToCustomLineItemFilter' {}
- newListResourcesAssociatedToCustomLineItemFilter :: ListResourcesAssociatedToCustomLineItemFilter
- listResourcesAssociatedToCustomLineItemFilter_relationship :: Lens' ListResourcesAssociatedToCustomLineItemFilter (Maybe CustomLineItemRelationship)
Documentation
data ListResourcesAssociatedToCustomLineItemFilter Source #
A filter that specifies the type of resource associations that should be retrieved for a custom line item.
See: newListResourcesAssociatedToCustomLineItemFilter smart constructor.
Constructors
| ListResourcesAssociatedToCustomLineItemFilter' | |
Fields
| |
Instances
newListResourcesAssociatedToCustomLineItemFilter :: ListResourcesAssociatedToCustomLineItemFilter Source #
Create a value of ListResourcesAssociatedToCustomLineItemFilter with all optional fields omitted.
Use generic-lens or optics to modify other optional fields.
The following record fields are available, with the corresponding lenses provided for backwards compatibility:
$sel:relationship:ListResourcesAssociatedToCustomLineItemFilter', listResourcesAssociatedToCustomLineItemFilter_relationship - The type of relationship between the custom line item and the associated
resource.
listResourcesAssociatedToCustomLineItemFilter_relationship :: Lens' ListResourcesAssociatedToCustomLineItemFilter (Maybe CustomLineItemRelationship) Source #
The type of relationship between the custom line item and the associated resource.